Django WalletOne
================

Django WalletOne is a pluggable application that integrates
with WalletOne online payments provider.

Django WalletOne supports Django 1.7 to 1.9 on Python 2.7, 3.4.

See https://django-walletone.readthedocs.org/ for application documentation.

See https://www.walletone.com/en/merchant/documentation/ for
native WalletOne documentation.
